@@ -136,6 +136,12 @@ class SAORMProvider(IProvider):
         fields = self.get_fields(entity)
         view_field = None
         for column_name in possible_names:
+            for actual_name in fields:
+                if column_name == actual_name:
+                    view_field = actual_name
+                    break
+            if view_field:
+                break;
             for actual_name in fields:
                 if column_name in actual_name:
                     view_field = actual_name
@@ -146,8 +152,9 @@ class SAORMProvider(IProvider):
             view_field = fields[0]
         return view_field
 
-    def get_dropdown_options(self, entity, field_name, view_names=['_name', 'name', 'description', 'title']):
-
+    def get_dropdown_options(self, entity, field_name, view_names=None):
+        if view_names is None:
+            view_names = ['_name', 'name', 'description', 'title']
         if self.session is None:
             warn('No dropdown options will be shown for %s.  '
                  'Try passing the session into the initialization'
